summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h')
-rw-r--r--kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h b/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
index ddc2030..abca654 100644
--- a/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
+++ b/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
@@ -50,7 +50,7 @@
* will be created containing the new balance value.
*
* @see MyMoneySeqAccessMgr::balance() and
* MyMoneySeqAccessMgr::tqinvalidateBalanceCache() for a usage example
*/
class MyMoneyBalanceCacheItem {
public:
@@ -286,11 +286,11 @@ public:
void modifyTransaction(const MyMoneyTransaction& transaction);
/**
- * This method re-tqparents an existing account
+ * This method re-parents an existing account
*
* An exception will be thrown upon error conditions.
*
- * @param account MyMoneyAccount reference to account to be re-tqparented
+ * @param account MyMoneyAccount reference to account to be re-parented
* @param tqparent MyMoneyAccount reference to new tqparent account
*/
void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& tqparent);
@@ -998,11 +998,11 @@ private:
/**
* This method is used to tqinvalidate the cached balance for
- * the selected account and all it's tqparents.
+ * the selected account and all it's parents.
*
* @param id id of the account in question
*/
- void tqinvalidateBalanceCache(const TQString& id);
+ void invalidateBalanceCache(const TQString& id);
/**
* This member variable keeps the User information.
@@ -1207,11 +1207,11 @@ private:
/**
- * This method re-tqparents an existing account
+ * This method re-parents an existing account
*
* An exception will be thrown upon error conditions.
*
- * @param account MyMoneyAccount reference to account to be re-tqparented
+ * @param account MyMoneyAccount reference to account to be re-parented
* @param tqparent MyMoneyAccount reference to new tqparent account
* @param sendNotification if true, notifications with the ids
* of all modified objects are send
@@ -50,7 +50,7 @@
*
* @see MyMoneySeqAccessMgr::balance() and
- * MyMoneySeqAccessMgr::tqinvalidateBalanceCache() for a usage example
+ * MyMoneySeqAccessMgr::invalidateBalanceCache() for a usage example
*/
class MyMoneyBalanceCacheItem {